@@ -1183,11 +1183,14 @@ pub fn object_property(p: &mut Parser) -> Option<CompletedMarker> {
         // }
         //
         // let b = {
-        //  set foo(bar) {
+        //  set [foo](bar) {
         //     return 5;
         //  }
         // }
-        T![ident] if (p.cur_src() == "get" || p.cur_src() == "set") && p.nth_at(1, T![ident]) => {
+        T![ident]
+            if (p.cur_src() == "get" || p.cur_src() == "set")
+                && (p.nth_at(1, T![ident]) || p.nth_at(1, T!['['])) =>
+        {
             method(p, None, None)
         }
         // test object_expr_async_method
